@@ -10,6 +10,10 @@ summary.GDINA <-
     "AIC penalty"=2*extract(object,"npar"),
     "AIC penalty due to item parameters"=2*extract(object,"npar.item"),
     "AIC penalty due to population parameters"=2*extract(object,"npar.att"),
+    "AICc"=extract(object,"AICc"),
+    "AICc penalty"=2*extract(object,"npar")*(extract(object,"npar")+1)/(extract(object,"nobs")-extract(object,"npar")-1),
+    "AICc penalty due to item parameters"=2*extract(object,"npar.item")*(extract(object,"npar.item")+1)/(extract(object,"nobs")-extract(object,"npar.item")-1),
+    "AICc penalty due to population parameters"=2*extract(object,"npar.att")*(extract(object,"npar.att")+1)/(extract(object,"nobs")-extract(object,"npar.att")-1),
     "BIC"=extract(object,"BIC"),
     "BIC penalty"=log(extract(object,"nobs"))*extract(object,"npar"),
     "BIC penalty due to item parameters"=log(extract(object,"nobs"))*extract(object,"npar.item"),
